@@ -9,7 +9,7 @@ use MooseX::Types::Moose qw(
         ArrayRef
         Bool
     );######<--------------------------------------------------------  ADD New types here
-use version; our $VERSION = qv('0.012.001');
+use version; our $VERSION = qv('0.012.002');
 if( $ENV{ Smart_Comments } ){
 	use Smart::Comments -ENV;
 	### Smart-Comments turned on for Data-Walk-Clone
@@ -233,7 +233,7 @@ memory references to the original memory references and so all of the Data::Walk
 skip methods will be recognized and supported.  Meaning that if a node is skipped the 
 data reference will be copied directly rather than cloned.  The deep clone boundaries 
 are managed using the L<skip attributes
-|https://metacpan.org/module/Data::Walk::Extracted#skipped_nodes> in Data::Walk::Extracted.
+|https://metacpan.org/module/Data::Walk::Extracted.pmE<35>skipped_nodes> in Data::Walk::Extracted.
 
 =head2 USE
 
@@ -249,7 +249,7 @@ for more class building information.
 Data passed to -E<gt>new when creating an instance.  For modification of these attributes 
 see L<Methods|/Methods>.  The -E<gt>new function will either accept fat comma lists or a 
 complete hash ref that has the possible attributes as the top keys.  Additionally 
-L<some attributes|https://metacpan.org/module/Data::Walk::Extracted#Supported one shot attributes> 
+L<some attributes|https://metacpan.org/module/Data::Walk::Extracted.pmE<35>Supported one shot attributes> 
 that have all the following methods; get_$attribute, set_$attribute, has_$attribute, and 
 clear_$attribute, can be passed to L<deep_clone|/deep_clone( $arg_ref|%args|$data_ref )> 
 and will be adjusted for just the run of that method call.  These are called 'one shot' 
@@ -269,7 +269,7 @@ B<Range> Boolean values (0|1)
 =back
 
 Attributes in 
-L<Data::Walk::Extracted|https://metacpan.org/module/Data::Walk::Extracted.pm#Attributes>
+L<Data::Walk::Extracted|https://metacpan.org/module/Data::Walk::Extracted.pmE<35>Attributes>
  - also affect the output.
 
 =head1 Methods
